@@ -35,7 +35,7 @@ class HTTP:
     Pointer, go to http://tools.ietf.org/html/draft-pbryan-zyp-json-pointer-00.
     """
 
-    ROBOT_LIBRARY_VERSION = "0.4.0"
+    ROBOT_LIBRARY_VERSION = "0.4.1"
 
     class Context(object):
         def __init__(self, http, host=None, scheme='http'):
@@ -125,7 +125,8 @@ class HTTP:
     @property
     def app(self):
         if not self.context.app:
-            raise Exception('Not connected to any HTTP Host. Use "Create HTTP Context" keyword first.')
+            raise Exception(
+                'Not connected to any HTTP Host. Use "Create HTTP Context" keyword first.')
         return self.context.app
 
     @property
@@ -291,7 +292,8 @@ class HTTP:
             raise Exception(
                 "Can not follow a response without a location header.")
 
-        logger.debug("Following response, last response's Location header was %s" % location)
+        logger.debug(
+            "Following response, last response's Location header was %s" % location)
 
         self.context.response = self.response.follow()
 
